==> v10.5.0.tar.gz: brewman/overlord/src/app/user/user-detail/user-detail.component.ts <==
import { AfterViewInit, Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { FormArray, FormControl, FormGroup } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';

import { ToasterService } from '../../core/toaster.service';
import { User } from '../../core/user';
import { ConfirmDialogComponent } from '../../shared/confirm-dialog/confirm-dialog.component';
import { UserService } from '../user.service';

@Component({
  selector: 'app-user-detail',
  templateUrl: './user-detail.component.html',
  styleUrls: ['./user-detail.component.css'],
})
export class UserDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('nameElement', { static: true }) nameElement?: ElementRef;
  form: FormGroup<{
    name: FormControl<string | null>;
    password: FormControl<string | null>;
    lockedOut: FormControl<boolean>;
    roles: FormArray<
      FormGroup<{
        role: FormControl<boolean>;
      }>
    >;
  }>;

  item: User = new User();
  hide: boolean;

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private toaster: ToasterService,
    private dialog: MatDialog,
    private ser: UserService,
  ) {
    this.hide = true;
    this.form = new FormGroup({
      name: new FormControl<string | null>(null),
      password: new FormControl<string | null>(null),
      lockedOut: new FormControl<boolean>(false, { nonNullable: true }),
      roles: new FormArray<FormGroup<{ role: FormControl<boolean> }>>([]),
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { item: User };

      this.showItem(data.item);
    });
  }

  showItem(item: User) {
    this.item = item;
    this.form.controls.name.setValue(item.name);
    this.form.controls.password.setValue(null);
    this.form.controls.lockedOut.setValue(item.lockedOut);
    this.item.roles.forEach((x) =>
      this.form.controls.roles.push(
        new FormGroup({
          role: new FormControl<boolean>(x.enabled, { nonNullable: true }),
        }),
      ),
    );
  }

  ngAfterViewInit() {
    setTimeout(() => {
      if (this.nameElement) {
        this.nameElement.nativeElement.focus();
      }
    }, 0);
  }

  save() {
    if (this.route.snapshot.paramMap.get('id') === 'me') {
      this.ser.updateMe(this.getItem()).subscribe(
        () => {
          this.toaster.show('Success', '');
          this.router.navigateByUrl('/');
        },
        (error) => {
          this.toaster.show('Danger', error);
        },
      );
    } else {
      this.ser.saveOrUpdate(this.getItem()).subscribe(
        () => {
          this.toaster.show('Success', '');
          this.router.navigateByUrl('/users');
        },
        (error) => {
          this.toaster.show('Danger', error);
        },
      );
    }
  }

  delete() {
    this.ser.delete(this.item.id as string).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/users');
      },
      (error) => {
        this.toaster.show('Danger', error);
      },
    );
  }

  confirmDelete(): void {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: { title: 'Delete User?', content: 'Are you sure? This cannot be undone.' },
    });

    dialogRef.afterClosed().subscribe((result: boolean) => {
      if (result) {
        this.delete();
      }
    });
  }

  getItem(): User {
    const formModel = this.form.value;
    this.item.name = formModel.name!;
    this.item.password = formModel.password!;
    this.item.lockedOut = formModel.lockedOut!;
    const array = this.form.controls.roles;
    this.item.roles.forEach((item, index) => {
      item.enabled = array.controls[index].value.role!;
    });
    return this.item;
  }
}

==> v11.1.0.tar.gz: brewman/overlord/src/app/user/user-detail/user-detail.component.ts <==
import { AfterViewInit, Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { FormArray, FormControl, FormGroup } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';

import { ToasterService } from '../../core/toaster.service';
import { User } from '../../core/user';
import { ConfirmDialogComponent } from '../../shared/confirm-dialog/confirm-dialog.component';
import { UserService } from '../user.service';

@Component({
  selector: 'app-user-detail',
  templateUrl: './user-detail.component.html',
  styleUrls: ['./user-detail.component.css'],
})
export class UserDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('nameElement', { static: true }) nameElement?: ElementRef;
  form: FormGroup<{
    name: FormControl<string | null>;
    password: FormControl<string | null>;
    lockedOut: FormControl<boolean>;
    roles: FormArray<
      FormGroup<{
        role: FormControl<boolean>;
      }>
    >;
  }>;

  item: User = new User();
  hide: boolean;

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private toaster: ToasterService,
    private dialog: MatDialog,
    private ser: UserService,
  ) {
    this.hide = true;
    this.form = new FormGroup({
      name: new FormControl<string | null>(null),
      password: new FormControl<string | null>(null),
      lockedOut: new FormControl<boolean>(false, { nonNullable: true }),
      roles: new FormArray<FormGroup<{ role: FormControl<boolean> }>>([]),
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { item: User };

      this.showItem(data.item);
    });
  }

  showItem(item: User) {
    this.item = item;
    this.form.controls.name.setValue(item.name);
    this.form.controls.password.setValue(null);
    this.form.controls.lockedOut.setValue(item.lockedOut);
    this.form.controls.roles.clear();
    this.item.roles.forEach((x) =>
      this.form.controls.roles.push(
        new FormGroup({
          role: new FormControl<boolean>(x.enabled, { nonNullable: true }),
        }),
      ),
    );
  }

  ngAfterViewInit() {
    setTimeout(() => {
      if (this.nameElement) {
        this.nameElement.nativeElement.focus();
      }
    }, 0);
  }

  save() {
    if (this.route.snapshot.paramMap.get('id') === 'me') {
      this.ser.updateMe(this.getItem()).subscribe(
        () => {
          this.toaster.show('Success', '');
          this.router.navigateByUrl('/');
        },
        (error) => {
          this.toaster.show('Danger', error);
        },
      );
    } else {
      this.ser.saveOrUpdate(this.getItem()).subscribe(
        () => {
          this.toaster.show('Success', '');
          this.router.navigateByUrl('/users');
        },
        (error) => {
          this.toaster.show('Danger', error);
        },
      );
    }
  }

  delete() {
    this.ser.delete(this.item.id as string).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/users');
      },
      (error) => {
        this.toaster.show('Danger', error);
      },
    );
  }

  confirmDelete(): void {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: { title: 'Delete User?', content: 'Are you sure? This cannot be undone.' },
    });

    dialogRef.afterClosed().subscribe((result: boolean) => {
      if (result) {
        this.delete();
      }
    });
  }

  getItem(): User {
    const formModel = this.form.value;
    this.item.name = formModel.name ?? '';
    this.item.password = formModel.password ?? '';
    this.item.lockedOut = formModel.lockedOut ?? true;
    const array = this.form.controls.roles;
    this.item.roles.forEach((item, index) => {
      item.enabled = array.controls[index].value.role ?? false;
    });
    return this.item;
  }
}
